# wagtail-rest-pack

# wagtail-rest-pack

=====
Wagtail Rest Pack
=====

Wagtail app easing development of single page application with specific complex needs. And for fun.

Deployment Backend
-----------
1. Push your changes
2. Increment version in setup.cfg
3. Start push.sh command, which pushes to repository
   
Deployment Frontend
-----------
1. Increment version in package.json
2. Push your changes
3. run "npm run build"
4. run "npm run publish"